@@ -1,5 +1,8 @@
 package Finance::Bank::ID::Base;
 
+our $DATE = '2015-03-28'; # DATE
+our $VERSION = '0.34'; # VERSION
+
 use 5.010;
 use Moo;
 use Log::Any;
@@ -10,8 +13,6 @@ use DateTime;
 use Finance::BankUtils::ID::Mechanize;
 use YAML::Syck qw(LoadFile DumpFile);
 
-our $VERSION = '0.33'; # VERSION
-
 has mech        => (is => 'rw');
 has username    => (is => 'rw');
 has password    => (is => 'rw');
@@ -39,7 +40,7 @@ sub _fmtdate {
 
 sub _fmtdt {
     my ($self, $dt) = @_;
-    $dt->ymd . ' ' . $dt->hms;
+    $dt->datetime;
 }
 
 sub _dmp {
@@ -278,7 +279,7 @@ Finance::Bank::ID::Base - Base class for Finance::Bank::ID::BCA etc
 
 =head1 VERSION
 
-This document describes version 0.33 of Finance::Bank::ID::Base (from Perl distribution Finance-Bank-ID-BCA), released on 2015-02-06.
+This document describes version 0.34 of Finance::Bank::ID::Base (from Perl distribution Finance-Bank-ID-BCA), released on 2015-03-28.
 
 =head1 SYNOPSIS
 
